OC.L10N.register(
    "calendar",
    {
    "User-Session unexpectedly expired" : "Korisnička sesija neočekivano je istekla",
    "Provided email-address is not valid" : "Unesena adresa e-pošte nije važeća",
    "%s has published the calendar »%s«" : "%s je objavio kalendar »%s«",
    "Unexpected error sending email. Please contact your administrator." : "Došlo je do pogreške pri slanju poruke e-pošte. Obratite se svom administratoru.",
    "Successfully sent email to " : "Poruka e-pošte uspješno poslana ",
    "Hello," : "Pozdrav,",
    "We wanted to inform you that %s has published the calendar »%s«." : "htjeli bismo vas obavijestiti da je %s objavio kalendar »%s«.",
    "Open »%s«" : "Otvori »%s«",
    "Cheers!" : "Bok!",
    "Calendar" : "Kalendar",
    "A Calendar app for Nextcloud" : "Aplikacija Kalendar za Nextcloud",
    "Previous day" : "Prethodni dan",
    "Previous week" : "Prethodni tjedan",
    "Previous month" : "Prethodni mjesec",
    "Next day" : "Sljedeći dan",
    "Next week" : "Sljedeći tjedan",
    "Next month" : "Sljedeći mjesec",
    "+ New event" : "+ Novi događaj",
    "Today" : "Danas",
    "Day" : "Dan",
    "Week" : "Tjedan",
    "Month" : "Mjesec",
    "Untitled calendar" : "Kalendar bez naslova",
    "Edit name" : "Uredi naziv",
    "Saving name …" : "Spremanje naziva ...",
    "Edit color" : "Uredi boju",
    "Saving color …" : "Spremanje boje ...",
    "Copy private link" : "Kopiraj privatnu poveznicu",
    "Download" : "Preuzmi",
    "Unshare from me" : "Prekid dijeljenja sa mnom",
    "Delete" : "Izbriši",
    "An error occurred, unable to change visibility of the calendar." : "Došlo je do pogreške, nije moguće promijeniti vidljivost kalendara.",
    "An error occurred, unable to delete the calendar." : "Došlo je do pogreške, nije moguće izbrisati kalendar.",
    "Calendar link copied to clipboard." : "Poveznica kalendara kopirana je u međuspremnik.",
    "Calendar link could not be copied to clipboard." : "Poveznica kalendara nije kopirana u međuspremnik.",
    "An error occurred, unable to rename the calendar." : "Došlo je do pogreške, nije moguće promijeniti naziv kalendara.",
    "An error occurred, unable to change the calendar's color." : "Došlo je do pogreške, nije moguće promijeniti boju kalendara.",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Prekid dijeljenja kalendara za {countdown} sekundu","Prekid dijeljenja kalendara za {countdown} sekunde","Prekid dijeljenja kalendara za {countdown} sekundi"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Brisanje kalendara za {countdown} sekundu","Brisanje kalendara za {countdown} sekunde","Brisanje kalendara za {countdown} sekundi"],
    "Share link" : "Dijeli poveznicu",
    "Publish calendar" : "Objavi kalendar",
    "Publishing calendar" : "Objavljivanje kalendara",
    "Copy public link" : "Kopiraj javnu poveznicu",
    "Send link to calendar via email" : "Pošalji poveznicu na kalendar putem e-pošte",
    "Enter one address" : "Unesi jednu adresu",
    "Sending email …" : "Slanje e-pošte u tijeku ...",
    "Copy subscription link" : "Kopiraj poveznicu pretplate",
    "Copying link …" : "Kopiranje poveznice ...",
    "Copied link" : "Poveznica je kopirana",
    "Could not copy link" : "Kopiranje poveznice nije uspjelo",
    "Copy embedding code" : "Kopiraj šifru za ugradnju",
    "Copying code …" : "Kopiranje poveznice ...",
    "Copied code" : "Šifra je kopirana",
    "Could not copy code" : "Kopiranje šifre nije uspjelo",
    "Delete share link" : "Izbriši poveznicu dijeljenja",
    "Deleting share link …" : "Brisanje poveznice dijeljenja ...",
    "An error occurred, unable to publish calendar." : "Došlo je do pogreške, nije moguće objaviti kalendar.",
    "An error occurred, unable to send email." : "Došlo je do pogreške, nije moguće poslati poruku e-pošte.",
    "Embed code copied to clipboard." : "Šifra za ugradnju kopirana je u međuspremnik.",
    "Embed code could not be copied to clipboard." : "Šifru za ugradnju nije moguće kopirati u međuspremnik.",
    "Unpublishing calendar failed" : "Neuspješan prekid objave kalendara",
    "Share with users or groups" : "Dijelite s korisnicima ili grupama",
    "No users or groups" : "Nema korisnika ili grupa",
    "can edit" : "uređivanje moguće",
    "Unshare with {displayName}" : "Prekid dijeljenja s {displayName}",
    "An error occurred, unable to change the unshare the calendar." : "Došlo je do pogreške, nije moguće promijeniti status dijeljenja kalendara.",
    "An error occurred, unable to change the permission of the share." : "Došlo je do pogreške, nije moguće promijeniti dopuštenje dijeljenja.",
    "+ New calendar" : "+ Novi kalendar",
    "New calendar" : "Novi kalendar",
    "Creating calendar …" : "Stvaranje kalendara ...",
    "New calendar with task list" : "Novi kalendar s popisom zadataka",
    "Creating subscription …" : "Stvaranje pretplate ...",
    "An error occurred, unable to create the calendar." : "Došlo je do pogreške, nije moguće stvoriti kalendar.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Unesite valjanu poveznicu (mora početi s http://, https://, webcal:// ili webcals://)",
    "Import calendars" : "Uvoz kalendara",
    "Please select a calendar to import into …" : "Odaberite kalendar za uvoz ...",
    "Filename" : "Naziv datoteke",
    "Calendar to import into" : "Kalendar za uvoz",
    "Cancel" : "Odustani",
    "_Import calendar_::_Import calendars_" : ["Uvezi kalendar","Uvezi kalendare","Uvezi kalendare"],
    "Import partially failed. Imported {accepted} out of {total}." : "Djelomično neuspješan uvoz. Uvezeno {accepted} od {total}.",
    "_Successfully imported %n event_::_Successfully imported %n events._" : ["Uspješan uvoz %n događaja","Uspješan uvoz %n događaja.","Uspješan uvoz %n događaja."],
    "Automatic" : "Automatsko",
    "Automatic ({detected})" : "Automatsko ({detected})",
    "New setting was not saved successfully." : "Nova postavka nije uspješno spremljena.",
    "Enable birthday calendar" : "Omogući kalendar rođendana",
    "Enable simplified editor" : "Omogući jednostavan uređivač",
    "Show weekends" : "Prikaži vikende",
    "Show week numbers" : "Prikaži brojeve tjedana",
    "Copy primary CalDAV address" : "Kopiraj primarnu CalDAV adresu",
    "Copy iOS/macOS CalDAV address" : "Kopiraj iOS/macOS CalDAV adresu",
    "Settings & import" : "Postavke i uvoz",
    "CalDAV link copied to clipboard." : "Poveznica kalendara CalDAV kopirana je u međuspremnik.",
    "CalDAV link could not be copied to clipboard." : "Poveznica kalendara CalDAV nije kopirana u međuspremnik.",
    "before at" : "prije u",
    "Notification" : "Obavijest",
    "Email" : "E-pošta",
    "Audio notification" : "Zvučna obavijest",
    "Other notification" : "Druga obavijest",
    "Relative to event" : "Povezano s događajem",
    "On date" : "Na datum",
    "Edit time" : "Uredi vrijeme",
    "Save time" : "Spremi vrijeme",
    "Remove reminder" : "Ukloni podsjetnik",
    "on" : "na",
    "at" : "u",
    "+ Add reminder" : "+ Dodaj podsjetnik",
    "_second_::_seconds_" : ["sekunda","sekunde","sekundi"],
    "_minute_::_minutes_" : ["minuta","minute","minuta"],
    "_hour_::_hours_" : ["sat","sata","sati"],
    "_day_::_days_" : ["dan","dana","dana"],
    "_week_::_weeks_" : ["tjedan","tjedna","tjedana"],
    "No reminders yet" : "Još nema podsjetnika",
    "Availability of attendees, resources and rooms" : "Raspoloživost sudionika, resursa i soba",
    "Attendees, Resources and Rooms" : "Sudionici, resursi i sobe",
    "Busy (tentative)" : "Zauzeto (uvjetno)",
    "Busy" : "Zauzeto",
    "Out of office" : "Izvan ureda",
    "Unknown" : "Nepoznato",
    "{name} accepted your invitation." : "{name} je prihvatio vaš poziv.",
    "{name} accepted {organizerName}'s invitation." : "{name} je prihvatio poziv {organizerName}.",
    "{name} declined your invitation." : "{name} je odbio vaš poziv.",
    "{name} declined {organizerName}'s invitation." : "{name} je odbio poziv {organizerName}.",
    "{name} has delegated their invitation." : "{name} je delegirao svoj poziv.",
    "{name} marked their participation as tentative." : "{name} je označio svoje sudjelovanje kao uvjetno.",
    "{name} did not respond to your invitation yet." : "{name} još nije odgovorio na vaš poziv.",
    "{name} did not respond to {organizerName}'s invitation yet." : "{name} još nije odgovorio na poziv {organizerName}.",
    "Create Talk room for this event" : "Stvori Talk sobu za ovaj događaj",
    "Show busy times" : "Prikaži vremena zauzetosti",
    "Successfully appended link to talk room to description." : "Uspješno dodana poveznica na Talk sobu u opis.",
    "Error creating Talk room" : "Pogreška pri stvaranju Talk sobe",
    "Send e-mail" : "Pošalji poruku e-pošte",
    "Chairperson" : "Predsjednik",
    "Required participant" : "Obavezan sudionik",
    "Optional participant" : "Neobavezan sudionik",
    "Non-participant" : "Nije sudionik",
    "Remove attendee" : "Ukloni sudionika",
    "Search for e-mails, users, contacts, resources or rooms" : "Traži poruke e-pošte, korisnike, kontakte, resurse ili sobe",
    "No match found" : "Nema podudaranja",
    "No attendees yet" : "Još nema sudionika",
    "(organizer)" : "(organizator)",
    "To send out invitations and handle responses,  [linkopen]add your email address in personal settings[linkclose]." : "[linkopen]Dodajte svoju adresu e-pošte u osobne postavke[linkclose] za slanje poziva i upravljanje odgovorima.",
    "Event title" : "Naslov događaja",
    "All day" : "Cijeli dan",
    "Can not modify all-day setting for events that are part of a recurrence-set." : "Nije moguće mijenjati cjelodnevne postavke za događaje koji su dio skupa ponavljanja.",
    "from {startDate}" : "od {startDate}",
    "from {startDate} at {startTime}" : "od {startDate} u {startTime}",
    "to {endDate}" : "do {endDate}",
    "to {endDate} at {endTime}" : "do {endDate} u {endTime}",
    "End repeat" : "Završi ponavljanje",
    "Select to end repeat" : "Odaberi za završetak ponavljanja",
    "never" : "nikad",
    "on date" : "na datum",
    "after" : "nakon",
    "_time_::_times_" : ["put","puta","puta"],
    "This event is the recurrence-exception of a recurrence-set. You can not add a recurrence-rule to it." : "Ovaj događaj je iznimka ponavljanja skupa ponavljanja. Ne možete mu dodati pravilo ponavljanja.",
    "first" : "prvi",
    "third" : "treći",
    "fourth" : "četvrti",
    "fifth" : "peti",
    "second to last" : "predzadnji",
    "last" : "zadnji",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Promjene pravila ponavljanja primjenjuju se na ovo i sva buduća ponavljanja.",
    "Repeat" : "Ponovi",
    "Repeat every" : "Ponovi svakih",
    "By day of the month" : "Do dana u mjesecu",
    "On the" : "Na",
    "_month_::_months_" : ["mjesec","mjeseca","mjeseci"],
    "_year_::_years_" : ["godinu","godine","godina"],
    "Monday" : "Ponedjeljak",
    "weekday" : "dan u tjednu",
    "weekend day" : "dan vikendom",
    "Summary" : "Sažetak",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Nextcloud ne podržava u potpunosti definiciju ponavljanja za ovaj događaj. Ako uredite mogućnosti ponavljanja, može doći do gubitka određenih ponavljanja.",
    "More" : "Više",
    "Save" : "Spremi",
    "Update" : "Ažurirajte",
    "Update this occurrence" : "Ažuriraj ovo ponavljanje",
    "Update this and all future" : "Ažuriraj ovo i sva buduća ponavljanja",
    "Public calendar does not exist" : "Javni kalendar ne postoji",
    "Maybe the share was deleted or has expired?" : "Možda je dijeljenje izbrisano ili je isteklo?",
    "Please select a timezone:" : "Odaberite vremensku zonu:",
    "Select Date" : "Odaberi datum",
    "Type to search timezone" : "Upišite za pretraživanje vremenskih zona",
    "Personal" : "Osobno",
    "The automatic timezone detection determined your timezone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your timezone manually in the calendar settings." : "Značajka automatskog otkrivanja vremenske zone utvrdila je vašu vremensku zonu kao UTC.\nVjerojatno zbog sigurnosnih mjera vašeg internetskog preglednika.\nRučno postavite vremensku zonu u postavkama kalendara.",
    "Delete this occurrence" : "Izbriši ovo ponavljanje",
    "Delete this and all future" : "Izbriši ovo i sva buduća ponavljanja",
    "Details" : "Pojedinosti",
    "Attendees" : "Sudionici",
    "Reminders" : "Podsjetnici",
    "Activity" : "Aktivnost",
    "Projects" : "Projekti",
    "Show more details" : "Prikaži više pojedinosti",
    "Close" : "Zatvori",
    "Subscribe to {name}" : "Pretplati se na {name}",
    "Download {name}" : "Preuzmi {name}",
    "Anniversary" : "Godišnjica",
    "Appointment" : "Dogovor",
    "Business" : "Poslovno",
    "Education" : "Obrazovno",
    "Holiday" : "Blagdan/praznik",
    "Meeting" : "Sastanak",
    "Miscellaneous" : "Razno",
    "Non-working hours" : "Neradni sati",
    "Not in office" : "Nije u uredu",
    "Phone call" : "Telefonski poziv",
    "Sick day" : "Bolovanje",
    "Special occasion" : "Poseban događaj",
    "Travel" : "Putovanje",
    "Vacation" : "Odmor",
    "Midnight on the day the event starts" : "Ponoć na dan početka događaja",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["%n dan prije početka događaja u {formattedHourMinute}","%n dana prije početka događaja u {formattedHourMinute}","%n dana prije početka događaja u {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["%n tjedan prije početka događaja u {formattedHourMinute}","%n tjedna prije početka događaja u {formattedHourMinute}","%n tjedana prije početka događaja u {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "na dan događaja u {formattedHourMinute}",
    "at the event's start" : "na početku događaja",
    "at the event's end" : "na završetku događaja",
    "{time} before the event starts" : "{time} prije početka događaja",
    "{time} before the event ends" : "{time} prije završetka događaja",
    "{time} after the event starts" : "{time} nakon početka događaja",
    "{time} after the event ends" : "{time} nakon završetka događaja",
    "on {time}" : "u {time}",
    "on {time} ({timezoneId})" : "u {time} ({timezoneId})",
    "Week {number} of {year}" : "{number} tjedan {year}",
    "Does not repeat" : "Ne ponavlja se",
    "Daily" : "Svaki dan",
    "Weekly" : "Svaki tjedan",
    "Monthly" : "Svaki mjesec",
    "Yearly" : "Svake godine",
    "_Every %n day_::_Every %n days_" : ["Svaki %n dan","Svaka %n dana","Svakih %n dana"],
    "_Every %n week_::_Every %n weeks_" : ["Svaki %n tjedan","Svaka %n tjedna","Svakih %n tjedana"],
    "_Every %n month_::_Every %n months_" : ["Svaki %n mjesec","Svaka %n mjeseca","Svakih %n mjeseci"],
    "_Every %n year_::_Every %n years_" : ["Svake %n godine","Svake %n godine","Svakih %n godina"],
    "_on {weekday}_::_on {weekdays}_" : ["{weekday}","{weekdays}","{weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["na dan {dayOfMonthList}","na dane {dayOfMonthList}","na dane {dayOfMonthList}"],
    "on the {ordinalNumber} {byDaySet}" : "{ordinalNumber} {byDaySet}",
    "in {monthNames}" : "u {monthNames}",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "u {monthNames} {ordinalNumber} {byDaySet}",
    "until {untilDate}" : "do {untilDate}",
    "_%n time_::_%n times_" : ["%n put","%n puta","%n puta"],
    "_+%n more_::_+%n more_" : ["+%n više","+%n više","+%n više"],
    "Untitled event" : "Događaj bez naslova",
    "When shared show" : "Kada se dijeli, prikaži",
    "When shared show full event" : "Kada se dijeli, prikaži cijeli događaj",
    "When shared show only busy" : "Kada se dijeli, prikaži samo zauzeto",
    "When shared hide this event" : "Kada se dijeli, sakrij događaj",
    "The visibility of this event in shared calendars." : "Vidljivost ovog događaja u dijeljenim kalendarima.",
    "Location" : "Lokacija",
    "Add a location" : "Dodaj lokaciju",
    "Description" : "Opis",
    "Add a description" : "Dodaj opis",
    "Status" : "Status",
    "Confirmed" : "Potvrđeno",
    "Tentative" : "Uvjetno",
    "Cancelled" : "Otkazano",
    "Confirmation about the overall status of the event." : "Potvrda cjelokupnog statusa događaja.",
    "Show as" : "Prikaži kao",
    "Take this event into account when calculating free-busy information." : "Uzmite ovaj događaj u obzir pri izračunu informacija o dostupnosti i zauzeću.",
    "Free" : "Dostupno",
    "Categories" : "Kategorije",
    "Categories help you to structure and organize your events." : "Kategorije vam pomažu odrediti strukturu i organizirati događaj.",
    "Search or add categories" : "Pretraži ili dodaj kategorije",
    "Add this as a new category" : "Dodaj kao novu kategoriju",
    "Custom color" : "Prilagođena boja",
    "Special color of this event. Overrides the calendar-color." : "Posebna boja ovog događaja. Primjenjuje se umjesto boje kalendara.",
    "Chat room for event" : "Soba za razmjenu poruka za događaj",
    "Imported {filename}" : "Uvezena datoteka {filename}",
    "Meditation" : "Meditacija",
    "Relaxing" : "Opuštanje",
    "Relax" : "Opustite se",
    "Presentation" : "Prezentacija",
    "Present" : "Prezentiraj",
    "Camping" : "Kampiranje",
    "Camp" : "Idi na kampiranje",
    "Movie" : "Film",
    "Cinema" : "Kino",
    "Graduation" : "Diplomiranje",
    "Brainstorm" : "Razmišljanje",
    "Baseball" : "Bejzbol",
    "Meet" : "Sastanak",
    "Review" : "Pregled",
    "Office" : "Ured",
    "Contributor week" : "Tjedan suradnika",
    "Party" : "Tulum",
    "Celebration" : "Proslava",
    "Mail" : "Pošta",
    "Soccer" : "Nogomet",
    "Football" : "Nogomet",
    "Gaming" : "Igranje",
    "Play" : "Zabava",
    "Game" : "Igra",
    "Drive" : "Vožnja",
    "Bicycle" : "Bicikl",
    "Cycle" : "Vožnja biciklom",
    "Biking" : "Biciklizam",
    "Podcast" : "Podcast",
    "Basketball" : "Košarka",
    "Fishing" : "Ribolov",
    "Hiking" : "Planinarenje",
    "Hike" : "Izlet",
    "Art" : "Umjetnost",
    "Exhibition" : "Izložba",
    "Museum" : "Muzej",
    "Pilates" : "Pilates",
    "Park" : "Park",
    "Studying" : "Učenje",
    "Doctor" : "Liječnik",
    "Health" : "Zdravlje",
    "Dentist" : "Stomatolog",
    "Interview" : "Razgovor",
    "Training" : "Trening",
    "Practice" : "Vježba",
    "Sports" : "Sport",
    "Exercise" : "Tjelovježba",
    "Work out" : "Vježba",
    "Working out" : "Vježbanje",
    "Barber" : "Brijač",
    "Haircut" : "Frizura",
    "Exam" : "Ispit",
    "Working" : "Rad",
    "New Years Eve" : "Stara godina",
    "NYE" : "NYE",
    "Fireworks" : "Vatromet",
    "Running" : "Trčanje",
    "Go for a run" : "Trčati",
    "Marathon" : "Maraton",
    "Call" : "Poziv",
    "Calling" : "Pozivanje",
    "Christmas" : "Božić",
    "Conference" : "Konferencija",
    "Pizza" : "Pizza",
    "Travelling" : "Putovanja",
    "Journey" : "Putovanje",
    "Collaborate" : "Suradnja",
    "Lecture" : "Predavanje",
    "Seminar" : "Seminar",
    "Photograph" : "Fotografija",
    "Celebrate" : "Slavlje",
    "Shopping" : "Kupnja",
    "Skate" : "Koturanje",
    "Skateboard" : "Daska za koturanje",
    "Wine tasting" : "Degustacija vina",
    "Golf" : "Golf",
    "Dinner" : "Večera",
    "Global" : "Globalno"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
